==> binaryclock_0.2.0-1.tar.gz: binaryclock-0.2.0/colorchooserbutton.cpp <==
/*
 *  Copyright 2010 Ruediger Gad
 *
 *  This file is part of Binary Clock.
 *
 *  Binary Clock is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Binary Clock is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "colorchooserbutton.h"

#include <QColorDialog>

ColorChooserButton::ColorChooserButton(QWidget *parent) :
    QPushButton(parent)
{
    connect(this, SIGNAL(clicked()), this, SLOT(openColorDialog()));
}

QColor ColorChooserButton::getColor(){
    return color;
}

void ColorChooserButton::openColorDialog(){
    QColor col = QColorDialog::getColor(color);
    if(col.isValid()){
        setColor(col);
    }
}

void ColorChooserButton::setColor(QColor color){
    this->color = color;

    setStyleSheet("background-color: rgb(" +
                  QString::number(color.red()) + "," +
                  QString::number(color.green()) + "," +
                  QString::number(color.blue()) + ");");
    /*
    QPalette palette;
    palette.setColor(backgroundRole(), this->color);
    setPalette(palette);
    */
}

==> binaryclock_0.6.1.tar.gz: binaryclock-0.6.1/colorchooserbutton.cpp <==
/*
 *  Copyright 2010 Ruediger Gad
 *
 *  This file is part of Binary Clock.
 *
 *  Binary Clock is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Binary Clock is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Binary Clock.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "colorchooserbutton.h"

#include <QColorDialog>

ColorChooserButton::ColorChooserButton(QWidget *parent) :
    QPushButton(parent)
{
    connect(this, SIGNAL(clicked()), this, SLOT(openColorDialog()));
}

QColor ColorChooserButton::getColor(){
    return color;
}

void ColorChooserButton::openColorDialog(){
    QColorDialog dialog;
    dialog.setCurrentColor(color);
    dialog.setAttribute(Qt::WA_QuitOnClose, false);

    if(dialog.exec()){
        setColor(dialog.currentColor());
    }
}

void ColorChooserButton::setColor(QColor color){
    this->color = color;

    setStyleSheet("background-color: rgb(" +
                  QString::number(color.red()) + "," +
                  QString::number(color.green()) + "," +
                  QString::number(color.blue()) + ");");
    /*
    QPalette palette;
    palette.setColor(backgroundRole(), this->color);
    setPalette(palette);
    */
}
